<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE mapper PUBLIC "-//mybatis.org//DTD Mapper 3.0//EN" "http://mybatis.org/dtd/mybatis-3-mapper.dtd">
<mapper namespace="${package.Mapper}.${table.mapperName}">

<#if baseResultMap>
    <!-- 通用查询映射结果 -->
    <resultMap id="BaseResultMap" type="${package.Entity}.${entity}">
<#list table.fields as field>
<#if field.keyFlag><#--生成主键排在第一位-->
        <id column="${field.name}" property="${field.propertyName}" />
</#if>
</#list>
<#list table.commonFields as field><#--生成公共字段 -->
    <result column="${field.name}" property="${field.propertyName}" />
</#list>
<#list table.fields as field>
<#if !field.keyFlag><#--生成普通字段 -->
        <result column="${field.name}" property="${field.propertyName}" />
</#if>
</#list>
    </resultMap>

</#if>

    <sql id="Table_Name">
        ${table.name}
    </sql>

<#if baseColumnList>
    <!-- 通用查询结果列 -->
    <sql id="Base_Column_List">
<#list table.commonFields as field>
        ${field.name},
</#list>
        ${table.fieldNames}
    </sql>

</#if>

    <!--新增操作 -->
    <insert id="save" parameterType="${package.Entity}.${entity}">
        insert into
        <include refid="Table_Name"/>
        (<include refid="Base_Column_List"/>)
        values(
      <#list table.fields as field>
        <#if field.propertyName != "createDate">
            <#if field_index gt 0>,</#if>${r"#{"}${field.propertyName}${r"}"}
        <#else>
            <#if field_index gt 0>,</#if> now()
        </#if>
      </#list>
         )
    </insert>

    <!--根据ID查询-->
    <select id="findById" resultMap="BaseResultMap" parameterType="String">
        select
        <include refid="Base_Column_List"/>
        from
        <include refid="Table_Name"/>
        where id = <#noparse>#</#noparse>{id}
    </select>

    <!--获取数据总数-->
    <select id="getCount" parameterType="java.util.Map" resultType="int">
        select count(*) from
        <include refid="Table_Name"/>
        where 1=1
        <include refid="sql_query"/>
        <include refid="fuzzySearch"/>
    </select>

    <!-- 查询所有数据-->
    <select id="findAll" resultMap="BaseResultMap">
        select
        <include refid="Base_Column_List"/>
        from
        <include refid="Table_Name"/>
        <!--ORDER BY `dt_create_date` DESC-->
   </select>

   <!-- 通过条件查询所有数据-->
    <select id="findByMap" parameterType="java.util.Map" resultMap="BaseResultMap">
        select
        <include refid="Base_Column_List"/>
        from
        <include refid="Table_Name"/>
        <where>
            <include refid="sql_query"/>
            <include refid="fuzzySearch"/>
        </where>
        <!--ORDER BY `dt_create_date` DESC-->
    </select>

    <!--分组分页查询-->
    <select id="findByPage" parameterType="java.util.Map" resultMap="BaseResultMap">
        SELECT
        <include refid="Base_Column_List"/>
        FROM
        <include refid="Table_Name"/>
        <where>
            <include refid="sql_query"/>
            <include refid="fuzzySearch"/>
        </where>
        <!--ORDER BY `dt_create_date` DESC-->
        limit <#noparse>#</#noparse>{startRowNum}, <#noparse>#</#noparse>{pageSize}
    </select>

    <!--更新-->
    <update id="update" parameterType="${package.Entity}.${entity}">
        update
        <include refid="Table_Name"/>
        <include refid="sql_update"/>
        where
         <#list table.fields as field>
             <#if field.keyFlag>
        ${field.name} = <#noparse>#{</#noparse>${field.propertyName}}
             </#if>
         </#list>
    </update>

    <!--根据ID删除-->
    <delete id="deleteById" parameterType="String">
        delete from
        <include refid="Table_Name"/>
        where
        <#list table.fields as field>
            <#if field.keyFlag>
        ${field.name} = <#noparse>#{</#noparse>${field.propertyName}}
            </#if>
        </#list>

    </delete>

    <sql id="fuzzySearch">
        <if test="keyword != null and keyword !=''">
            and (locate(<#noparse>#</#noparse>{keyword,jdbcType=VARCHAR}, s_name)>0
            )
        </if>
    </sql>

    <sql id="sql_query">
        <#list table.fields as field>
             <if test="${field.propertyName} != null and ${field.propertyName} != '' ">
                 <![CDATA[ and ${field.name} = <#noparse>#{</#noparse>${field.propertyName}}]]>
             </if>
        </#list>
    </sql>

    <!--更新操作-->
    <sql id="sql_update">
        <set>
            <#list table.fields as field>
            <if test="${field.propertyName} != null and ${field.propertyName} != '' ">
                <![CDATA[ ${field.name} = <#noparse>#{</#noparse>${field.propertyName}}, ]]>
            </if>
            </#list>
        </set>
    </sql>

</mapper>
